@@ -181,6 +181,11 @@ def dumps(doc: Document, fragment_newlines: bool = True) -> str:
     for e in doc.entities:
         existing_eids.add(e.id)
         line = ""
+        while e.text[0].isspace():
+            s = list(map(lambda x: list(x), e.span))
+            s[0][0] += 1
+            e.span = tuple(map(lambda x: (x[0], x[1]), s))
+            e.text = e.text[1:]
         if "\n" in e.text and fragment_newlines:
             fragmented_entity = fragment_entity(e)
             line = get_fragmented_line(fragmented_entity)
